<?php namespace App\Http\Controllers;

use App\Models\Menu;
use App\Models\MenuCategory;

use App\Http\Helpers\Helpers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;

class MenuController extends Controller {

    protected $rules = [
        'name' => ['required'],
        'price' => ['required'],
    ];

    public function __construct() {
        $this->middleware('auth');
        $this->helper = new Helpers();
    }

    public function index() {
        return view('admin.menu.index', [
            'items' => MenuCategory::orderBy('sorting', 'ASC')->get()
        ]);
    }

    public function lists($id) {
        return view('admin.menu.lists', [
            'items' => Menu::where('menu_category_id', $id)->orderBy('menu_category_id')->orderBy('sorting', 'ASC')->get(),
            'name' => MenuCategory::find($id)
        ]);
    }

    public function create() {
        return view('admin.menu.create', [
            'categories' => MenuCategory::orderBy('name')->pluck('name', 'id')
        ]);
    }

    public function store(Request $request) {
        $this->validate($request, $this->rules);
        $input = $request->all();
        $last = Menu::orderBy('sorting', 'DESC')->first();
        $input['sorting'] = $last->sorting + 1;
        Menu::create($input);
        return Redirect::route('admin.menu.lists', $input['menu_category_id'])->with('message', 'Menu item successfully created!');
    }

    public function save(Request $request) {
        $item = Menu::find($request->pk);
        $item->update(array($request->name => $request->value));
        die('Saved!');
    }

    public function getCategories() {
        $items = MenuCategory::get(['id', 'name']);
        $arr = array();
        foreach($items as $item) {
            $arr[] = array('value' => $item->id, 'text' => $item->name);
        }
        die(json_encode($arr));
    }


}
