<?php

namespace App\Helpers\Bootstrap;

/**
 * Custom made helper for the Bootstrap theme
 *
 * @copyright SPIN Internet Media
 * @author Alvin Bakker
 * @date 01/09/2015
 */

use Collective\Html;

class BootstrapHelper {

    /**
     * Alert builder
     * @param $type = danger, warning, success, info
     * @param $header
     * @param $body
     * @return string
     */
    public static function alert($type, $header, $body) {
        $alert  = '<div class="alert alert-block alert-' . $type . ' fade in">';
	    $alert .= '<button type="button" class="close" data-dismiss="alert"></button>';
		$alert .= '<h4 class="alert-heading">' . $header . '</h4>';
        $alert .= '<p>' . $body . '</p>';
        $alert .= '</div>';
        return $alert;
    }

    /**
     * Modal builder
     * @param $header
     * @param $body
     * @return string
     */
    public static function modal($header, $body) {
        $modal  = '<div class="modal fade in" id="basic" tabindex="-1" role="basic" aria-hidden="false" style="display: none; padding-right: 17px;">';
        $modal .= '<div class="modal-dialog">';
        $modal .= '<div class="modal-content">';
        $modal .= '<div class="modal-header">';
        $modal .= '<button type="button" class="close" data-dismiss="modal" aria-hidden="true"></button>';
        $modal .= '<h4 class="modal-title">' . $header . '</h4>';
        $modal .= '</div>';
        $modal .= '<div class="modal-body">' . $body . '</div>';
        $modal .= '<div class="modal-footer"><button type="button" class="btn default" data-dismiss="modal">Close</button></div>';
        $modal .= '</div>';
        $modal .= '</div>';
        $modal .= '</div>';
        return $modal;
    }

    /**
     * Start form builder
     * @return string
     */
    public static function startForm() {
        $form  = '<div class="form-horizontal form">';
        $form .= '<div class="form-body">';
        return $form;
    }

    /**
     * End form builder
     * @return string
     */
    public static function endForm() {
        $form = '</div>';
        $form .= '</div>';
        return $form;
    }


    /**
     * Text input builder
     * @param $type
     * @param $label
     * @param $name
     * @param null $placeholder
     * @param null $explanation
     * @param null $value
     * @return string
     */
    public static function formInput($type, $label, $name, $placeholder = null, $explanation = null, $value = null, $error = null) {
        $class = null;
        if ($error) $class = 'has-error';
        $input  = '<div class="form-group ' . $class . '">';
        $input .= Html\FormFacade::label($name, $label, ['class' => 'col-md-2 control-label']);
        $input .= '<div class="col-md-9">';
        $input .= Html\FormFacade::input($type, $name, $value, ['class' => 'form-control', 'placeholder' => $placeholder]);
        $input .= '</div>';
        $input .= '<span class="help-block col-md-offset-2 col-md-9">'. $explanation . '</span>';
        $input .= '</div>';
        return $input;
    }

    /**
     * Select input builder
     * @param $label
     * @param $name
     * @param null $explanation
     * @param $array
     * @param string $blank
     * @return string
     */
    public static function formSelect($label, $name, $array, $explanation = null, $blank = 'Select', $error = null) {
        $class = null;
        if ($error) $class = 'has-error';
        $select  = '<div class="form-group ' . $class . '"">';
        $select .= Html\FormFacade::label($name, $label, ['class' => 'col-md-2 control-label']);
        $select .= '<div class="col-md-9">';
        $select .= Html\FormFacade::select($name, $array, $blank, ['class' => 'form-control']);
        $select .= '</div>';
        $select .= '<span class="help-block col-md-offset-2 col-md-9">'. $explanation . '</span>';
        $select .= '</div>';
        return $select;
    }

    /**
     * Textarea builder
     * @param $label
     * @param $name
     * @param null $explanation
     * @param null $value
     * @return string
     */
    public static function formTextarea($label, $name, $explanation = null, $value = null, $error = null) {
        $class = null;
        if ($error) $class = 'has-error';
        $text  = '<div class="form-group ' . $class . '">';
        $text .= Html\FormFacade::label($name, $label, ['class' => 'col-md-2 control-label']);
        $text .= '<div class="col-md-9">';
        $text .= Html\FormFacade::textarea($name, $value, ['class' => 'form-control']);
        $text .= '</div>';
        $text .= '<span class="help-block col-md-offset-2 col-md-10">'. $explanation . '</span>';
        $text .= '</div>';
        return $text;
    }

    /**
     * Checkbox builder
     * @param $label
     * @param $name
     * @param null $explanation
     * @param null $value
     * @param null $checked
     * @param null $error
     * @return string
     */
    public static function formCheck($label, $name, $explanation = null, $value = null, $checked = null, $error = null) {
        $class = null;
        if ($error) $class = 'has-error';
        $check  = '<div class="form-group ' . $class . '">';
        $check .= '<label class="col-md-2 control-label">' . $label . '</label>';
        $check .= '<div class="col-md-9">';
        $check .= '<div class="checkbox-list">';
        $check .= Html\FormFacade::checkbox($name, $value, $checked);
        $check .= '</div>';
        $check .= '</div>';
        $check .= '<span class="help-block col-md-offset-2 col-md-9">'. $explanation . '</span>';
        $check .= '</div>';
        return $check;
    }

    /**
     * Radio button builder
     * @param $label
     * @param $name
     * @param null $explanation
     * @param array $value
     * @param null $error
     * @return string
     */
    public static function formRadio($label, $name, $explanation = null, $value = array(), $error = null) {
        $class = null;
        if ($error) $class = 'has-error';
        $check  = '<div class="form-group ' . $class . '">';
        $check .= '<label class="col-md-2 control-label">' . $label . '</label>';
        $check .= '<div class="col-md-9">';
        $check .= '<div class="radio-list">';
        foreach ($value as $key => $value) {
            $check .= '<label><input type="radio" name="' . $name . '" value="' . $value . '" id="' . $name . $key . '"> ' . $value . '</label>';
        }
        $check .= '</div>';
        $check .= '</div>';
        $check .= '<span class="help-block col-md-offset-2 col-md-9">'. $explanation . '</span>';
        $check .= '</div>';
        return $check;
    }

    /**
     * Submit button creator
     * @param $name
     * @return string
     */
    public static function formSubmit($name) {
        $submit  = '<div class="form-group">';
        $submit .= '<label class="col-md-2 control-label no-semicolon">&nbsp;</label>';
        $submit .= '<div class="col-md-9">';
        $submit .= '<button id="this-form-submit" type="submit" class="btn btn-primary">' . $name . '</button>';
        $submit .= '</div>';
        $submit .= '</div>';
        return $submit;
    }

}